#ifndef LICENSEDLG_H
#define LICENSEDLG_H

#include <QtGui/QDialog>

namespace Ui {
    class LicenseDlg;
}

class LicenseDlg : public QDialog {
    Q_OBJECT
    Q_DISABLE_COPY(LicenseDlg)
public:
    //! Constructor.
    explicit LicenseDlg(QWidget *parent = 0);
    //! Destructor.
    virtual ~LicenseDlg();

private:
    Ui::LicenseDlg *m_ui;
};
#endif // LICENSEDLG_H
